$ErrorActionPreference = "Stop"

Set-ExecutionPolicy Bypass -Scope Process -Force

$env:chocolateyUseWindowsCompression = 'true'
$env:ChocolateyInstall = Convert-Path "$((Get-Command choco).path)\..\.."
Import-Module "$env:ChocolateyInstall\helpers\chocolateyProfile.psm1"

choco config set --name="'stopOnFirstPackageFailure'" --value="'true'"

function Write-PackageInstall($package) {
  Write-Output ""
  Write-Output "----------------------------------------------"
  Write-Output "Installing $package"
  Write-Output "----------------------------------------------"
  Write-Output ""
}
function Install-ChocoPackage($package, $options) {
  Write-PackageInstall $package
  choco install -y $package $options
  if ($LastExitCode -ne 0) {
     throw 'Error installing with Chocolatey'
  }
}

# Gradle
$GRADLE_VERSION = "6.5"
Install-ChocoPackage  -package gradle -options --version=$GRADLE_VERSION

# Maven
$APACHE_MAVEN = "3.6.3"
Install-ChocoPackage  -package maven -options --version=$APACHE_MAVEN

# Ant
$APACHE_ANT = "1.10.8"
$ANT_DOWNLOAD_URL = "http://ftp.heanet.ie/mirrors/www.apache.org/dist//ant/binaries/apache-ant-$APACHE_ANT-bin.zip"
$ANT_DOWNLOAD_SHA = "24a49f9efd19d1202700192ba811e4a0a714b2e16a37ca8124309ddec6754a22fa12c7e5a07d35a41a104c6b6bb514d5c99a2438b758e5b6c75cc583a2b2385f"

Write-Output "Downloading Ant $APACHE_ANT"
Invoke-WebRequest $ANT_DOWNLOAD_URL -OutFile Ant.zip

if ((Get-FileHash Ant.zip -Algorithm sha512).Hash -ne $ANT_DOWNLOAD_SHA) {
  Write-Output 'CHECKSUM VERIFICATION FAILED!'
  exit 1
} else {
  Write-Output 'Verified checksum'
}

Write-Output "Installing Ant $APACHE_ANT"

Expand-Archive Ant.zip -DestinationPath C:\
Remove-Item -Force Ant.zip

# Update the system path
$oldSysPath = (Get-Itemproperty -path 'hklm:\system\currentcontrolset\control\session manager\environment' -Name Path).Path
$newSysPath = $oldSysPath + ";C:\apache-ant-1.10.8\bin;"
Set-ItemProperty -path 'hklm:\system\currentcontrolset\control\session manager\environment' -Name Path -Value $newSysPath

Set-ItemProperty -path 'hklm:\system\currentcontrolset\control\session manager\environment' -Name ANT_HOME -Value "C:\apache-ant-1.10.8"


# Java
$JAVA_VERSION = "14.0.1"
Install-ChocoPackage  -package openjdk -options --version=$JAVA_VERSION
